"""LangChain integration for ClickZetta.

This package provides LangChain integrations for ClickZetta, including:
- SQL queries with ClickZettaSQLChain
- Vector storage with ClickZettaVectorStore
- Full-text search capabilities
- Chat message history storage
"""

from langchain_clickzetta.chat_message_histories import ClickZettaChatMessageHistory
from langchain_clickzetta.engine import ClickZettaEngine
from langchain_clickzetta.hybrid_store import (
    ClickZettaHybridStore,
    ClickZettaUnifiedRetriever,
)
from langchain_clickzetta.retrievers import (
    ClickZettaFullTextRetriever,
    ClickZettaHybridRetriever,
)
from langchain_clickzetta.sql_chain import ClickZettaSQLChain
from langchain_clickzetta.stores import (
    ClickZettaDocumentStore,
    ClickZettaFileStore,
    ClickZettaStore,
)
from langchain_clickzetta.vectorstores import ClickZettaVectorStore
from langchain_clickzetta.volume_store import (
    ClickZettaNamedVolumeStore,
    ClickZettaTableVolumeStore,
    ClickZettaUserVolumeStore,
    ClickZettaVolumeStore,
)

__version__ = "0.1.4"

__all__ = [
    "ClickZettaEngine",
    "ClickZettaSQLChain",
    "ClickZettaVectorStore",
    "ClickZettaChatMessageHistory",
    "ClickZettaFullTextRetriever",
    "ClickZettaHybridRetriever",
    "ClickZettaHybridStore",
    "ClickZettaUnifiedRetriever",
    "ClickZettaStore",
    "ClickZettaDocumentStore",
    "ClickZettaFileStore",
    "ClickZettaVolumeStore",
    "ClickZettaUserVolumeStore",
    "ClickZettaTableVolumeStore",
    "ClickZettaNamedVolumeStore",
]
